@@ -132,10 +132,6 @@ void tst_XmlPatterns::xquerySupport()
     if(m_dontRun)
         QSKIP("The command line utility is not in the path.");
 
-#ifdef Q_OS_WINCE
-    QSKIP("WinCE: This test uses unsupported WinCE functionality");
-#endif
-
 #ifndef QT_NO_PROCESS
     QFETCH(int,         expectedExitCode);
     QFETCH(QByteArray,  expectedQueryOutput);
@@ -234,10 +230,6 @@ void tst_XmlPatterns::xquerySupport()
 
 void tst_XmlPatterns::xquerySupport_data() const
 {
-#if defined(Q_OS_WINCE)
-    return;
-#endif
-
     QString path = QFINDTESTDATA("queries/");
 
     /* Check one file for existence, to avoid possible false positives. */
@@ -876,10 +868,6 @@ void tst_XmlPatterns::xsltSupport_data() const
     if(m_dontRun)
         QSKIP("The command line utility is not in the path.");
 
-#ifdef Q_OS_WINCE
-    QSKIP("WinCE: This test uses unsupported WinCE functionality");
-#endif
-
     QString spath = QFINDTESTDATA("stylesheets/");
     QString qpath = QFINDTESTDATA("queries/");
 
@@ -1040,7 +1028,7 @@ void tst_XmlPatterns::xsltSupport_data() const
 */
 QString tst_XmlPatterns::filterStderr(const QString &in)
 {
-    static QList<QRegExp> irrelevant = QList<QRegExp>()
+    static const QList<QRegExp> irrelevant = QList<QRegExp>()
 
         // specific filenames
         << QRegExp(QLatin1String("file:\\/\\/.*(\\.xq|\\.gccxml|\\.xml|\\.xsl|-)(,|:)"))
@@ -1048,12 +1036,12 @@ QString tst_XmlPatterns::filterStderr(const QString &in)
         // warning messages about old-style plugins
         << QRegExp(QLatin1String("Old plugin format found in lib [^\n]+\n"))
         << QRegExp(QLatin1String("Qt plugin loader: Compatibility plugin [^\n]+\n"))
+        << QRegExp(QLatin1String("Unimplemented code.\n"))
     ;
 
     QString out = in;
-    foreach (const QRegExp& rx, irrelevant) {
+    for (const QRegExp& rx : irrelevant)
         out = out.remove(rx);
-    }
 
     return out;
 }
